@@ -2,11 +2,13 @@
 
 namespace Sabre\VObject\Recur;
 
-use InvalidArgumentException;
-use DateTime;
 use DateTimeZone;
+use DateTimeImmutable;
+use DateTimeInterface;
+use InvalidArgumentException;
 use Sabre\VObject\Component;
 use Sabre\VObject\Component\VEvent;
+use Sabre\VObject\Settings;
 
 /**
  * This class is used to determine new for a recurring event, when the next
@@ -71,7 +73,7 @@ class EventIterator implements \Iterator {
     protected $allDay = false;
 
     /**
-     * Creates the iterator
+     * Creates the iterator.
      *
      * There's three ways to set up the iterator.
      *
@@ -89,9 +91,9 @@ class EventIterator implements \Iterator {
      * @param DateTimeZone $timeZone Reference timezone for floating dates and
      *                               times.
      */
-    public function __construct($input, $uid = null, DateTimeZone $timeZone = null) {
+    function __construct($input, $uid = null, DateTimeZone $timeZone = null) {
 
-        if (is_null($this->timeZone)) {
+        if (is_null($timeZone)) {
             $timeZone = new DateTimeZone('UTC');
         }
         $this->timeZone = $timeZone;
@@ -100,7 +102,7 @@ class EventIterator implements \Iterator {
             $events = $input;
         } elseif ($input instanceof VEvent) {
             // Single instance mode.
-            $events = array($input);
+            $events = [$input];
         } else {
             // Calendar + UID mode.
             $uid = (string)$uid;
@@ -114,7 +116,7 @@ class EventIterator implements \Iterator {
 
         }
 
-        foreach($events as $vevent) {
+        foreach ($events as $vevent) {
 
             if (!isset($vevent->{'RECURRENCE-ID'})) {
 
@@ -149,9 +151,9 @@ class EventIterator implements \Iterator {
 
         if (isset($this->masterEvent->EXDATE)) {
 
-            foreach($this->masterEvent->EXDATE as $exDate) {
+            foreach ($this->masterEvent->EXDATE as $exDate) {
 
-                foreach($exDate->getDateTimes($this->timeZone) as $dt) {
+                foreach ($exDate->getDateTimes($this->timeZone) as $dt) {
                     $this->exceptions[$dt->getTimeStamp()] = true;
                 }
 
@@ -166,7 +168,7 @@ class EventIterator implements \Iterator {
         } elseif (isset($this->masterEvent->DURATION)) {
             $duration = $this->masterEvent->DURATION->getDateInterval();
             $end = clone $this->startDate;
-            $end->add($duration);
+            $end = $end->add($duration);
             $this->eventDuration = $end->getTimeStamp() - $this->startDate->getTimeStamp();
         } elseif ($this->allDay) {
             $this->eventDuration = 3600 * 24;
@@ -186,10 +188,10 @@ class EventIterator implements \Iterator {
             );
         } else {
             $this->recurIterator = new RRuleIterator(
-                array(
-                    'FREQ' => 'DAILY',
+                [
+                    'FREQ'  => 'DAILY',
                     'COUNT' => 1,
-                ),
+                ],
                 $this->startDate
             );
         }
@@ -204,9 +206,9 @@ class EventIterator implements \Iterator {
     /**
      * Returns the date for the current position of the iterator.
      *
-     * @return DateTime
+     * @return DateTimeImmutable
      */
-    public function current() {
+    function current() {
 
         if ($this->currentDate) {
             return clone $this->currentDate;
@@ -218,9 +220,9 @@ class EventIterator implements \Iterator {
      * This method returns the start date for the current iteration of the
      * event.
      *
-     * @return DateTime
+     * @return DateTimeImmutable
      */
-    public function getDtStart() {
+    function getDtStart() {
 
         if ($this->currentDate) {
             return clone $this->currentDate;
@@ -232,16 +234,15 @@ class EventIterator implements \Iterator {
      * This method returns the end date for the current iteration of the
      * event.
      *
-     * @return DateTime
+     * @return DateTimeImmutable
      */
-    public function getDtEnd() {
+    function getDtEnd() {
 
         if (!$this->valid()) {
-            return null;
+            return;
         }
         $end = clone $this->currentDate;
-        $end->modify('+' . $this->eventDuration . ' seconds');
-        return $end;
+        return $end->modify('+' . $this->eventDuration . ' seconds');
 
     }
 
@@ -253,7 +254,7 @@ class EventIterator implements \Iterator {
      *
      * @return VEvent
      */
-    public function getEventObject() {
+    function getEventObject() {
 
         if ($this->currentOverriddenEvent) {
             return $this->currentOverriddenEvent;
@@ -292,7 +293,7 @@ class EventIterator implements \Iterator {
      *
      * @return int
      */
-    public function key() {
+    function key() {
 
         // The counter is always 1 ahead.
         return $this->counter - 1;
@@ -305,8 +306,11 @@ class EventIterator implements \Iterator {
      *
      * @return bool
      */
-    public function valid() {
+    function valid() {
 
+        if ($this->counter > Settings::$maxRecurrences && Settings::$maxRecurrences !== -1) {
+            throw new MaxInstancesExceededException('Recurring events are only allowed to generate ' . Settings::$maxRecurrences);
+        }
         return !!$this->currentDate;
 
     }
@@ -314,12 +318,12 @@ class EventIterator implements \Iterator {
     /**
      * Sets the iterator back to the starting point.
      */
-    public function rewind() {
+    function rewind() {
 
         $this->recurIterator->rewind();
         // re-creating overridden event index.
-        $index = array();
-        foreach($this->overriddenEvents as $key=>$event) {
+        $index = [];
+        foreach ($this->overriddenEvents as $key => $event) {
             $stamp = $event->DTSTART->getDateTime($this->timeZone)->getTimeStamp();
             $index[$stamp] = $key;
         }
@@ -340,7 +344,7 @@ class EventIterator implements \Iterator {
      *
      * @return void
      */
-    public function next() {
+    function next() {
 
         $this->currentOverriddenEvent = null;
         $this->counter++;
@@ -359,7 +363,7 @@ class EventIterator implements \Iterator {
                 }
                 $nextDate = $this->recurIterator->current();
                 $this->recurIterator->next();
-            } while(isset($this->exceptions[$nextDate->getTimeStamp()]));
+            } while (isset($this->exceptions[$nextDate->getTimeStamp()]));
 
         }
 
@@ -395,11 +399,11 @@ class EventIterator implements \Iterator {
     /**
      * Quickly jump to a date in the future.
      *
-     * @param DateTime $dateTime
+     * @param DateTimeInterface $dateTime
      */
-    public function fastForward(DateTime $dateTime) {
+    function fastForward(DateTimeInterface $dateTime) {
 
-        while($this->valid() && $this->getDtEnd() < $dateTime ) {
+        while ($this->valid() && $this->getDtEnd() < $dateTime) {
             $this->next();
         }
 
@@ -410,14 +414,14 @@ class EventIterator implements \Iterator {
      *
      * @return bool
      */
-    public function isInfinite() {
+    function isInfinite() {
 
         return $this->recurIterator->isInfinite();
 
     }
 
     /**
-     * RRULE parser
+     * RRULE parser.
      *
      * @var RRuleIterator
      */
@@ -442,7 +446,7 @@ class EventIterator implements \Iterator {
      *
      * @var array
      */
-    protected $overriddenEvents = array();
+    protected $overriddenEvents = [];
 
     /**
      * Overridden event index.
@@ -460,10 +464,10 @@ class EventIterator implements \Iterator {
      *
      * @var array
      */
-    protected $exceptions = array();
+    protected $exceptions = [];
 
     /**
-     * Internal event counter
+     * Internal event counter.
      *
      * @var int
      */
@@ -472,14 +476,14 @@ class EventIterator implements \Iterator {
     /**
      * The very start of the iteration process.
      *
-     * @var DateTime
+     * @var DateTimeImmutable
      */
     protected $startDate;
 
     /**
-     * Where we are currently in the iteration process
+     * Where we are currently in the iteration process.
      *
-     * @var DateTime
+     * @var DateTimeImmutable
      */
     protected $currentDate;
 
@@ -489,8 +493,15 @@ class EventIterator implements \Iterator {
      * Sometimes we need to temporary store the next date, because an
      * overridden event came before.
      *
-     * @var DateTime
+     * @var DateTimeImmutable
      */
     protected $nextDate;
 
+    /**
+     * The event that overwrites the current iteration
+     *
+     * @var VEVENT
+     */
+    protected $currentOverriddenEvent;
+
 }
