@@ -37,16 +37,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -54,6 +54,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140716T120000Z
 SUMMARY:B-day party
@@ -63,11 +64,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -145,16 +146,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -162,6 +163,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140726T120000Z
 SUMMARY:Daily sprint
@@ -171,6 +173,7 @@ ATTENDEE;PARTSTAT=ACCEPTED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140724T120000Z
 SUMMARY:Daily sprint
@@ -180,6 +183,7 @@ ATTENDEE;PARTSTAT=DECLINED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140728T120000Z
 SUMMARY:Daily sprint
@@ -189,6 +193,7 @@ ATTENDEE;PARTSTAT=TENTATIVE;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140729T120000Z
 SUMMARY:Daily sprint
@@ -198,6 +203,7 @@ ATTENDEE;PARTSTAT=ACCEPTED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140725T120000Z
 SUMMARY:Daily sprint
@@ -208,11 +214,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -288,16 +294,16 @@ ICS;
 
     $version = \Sabre\VObject\Version::VERSION;
 
-    $expected = array(
-        array(
-            'uid' => 'foobar',
-            'method' => 'REPLY',
-            'component' => 'VEVENT',
-            'sender' => 'mailto:one@example.org',
-            'senderName' => 'One',
-            'recipient' => 'mailto:strunk@example.org',
+    $expected = [
+        [
+            'uid'           => 'foobar',
+            'method'        => 'REPLY',
+            'component'     => 'VEVENT',
+            'sender'        => 'mailto:one@example.org',
+            'senderName'    => 'One',
+            'recipient'     => 'mailto:strunk@example.org',
             'recipientName' => 'Strunk',
-            'message' => <<<ICS
+            'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -305,6 +311,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140726
 RECURRENCE-ID;VALUE=DATE:20140726
@@ -313,6 +320,7 @@ ATTENDEE;PARTSTAT=ACCEPTED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140724
 RECURRENCE-ID;VALUE=DATE:20140724
@@ -321,6 +329,7 @@ ATTENDEE;PARTSTAT=DECLINED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140728
 RECURRENCE-ID;VALUE=DATE:20140728
@@ -329,6 +338,7 @@ ATTENDEE;PARTSTAT=TENTATIVE;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140729
 RECURRENCE-ID;VALUE=DATE:20140729
@@ -337,6 +347,7 @@ ATTENDEE;PARTSTAT=ACCEPTED;CN=One:mailto:one@example.org
 END:VEVENT
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140725
 RECURRENCE-ID;VALUE=DATE:20140725
@@ -346,11 +357,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -384,8 +395,8 @@ END:VCALENDAR
 ICS;
 
 
-        $expected = array();
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $expected = [];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -419,16 +430,16 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -436,6 +447,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140716T120000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
@@ -443,10 +455,10 @@ ATTENDEE;PARTSTAT=NEEDS-ACTION;CN=One:mailto:one@example.org
 END:VEVENT
 END:VCALENDAR
 ICS
-            )
+            ]
 
-        );
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        ];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -479,8 +491,8 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $expected = array();
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $expected = [];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -525,16 +537,16 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => null,
-                'recipient' => 'mailto:organizer@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => null,
+                'recipient'     => 'mailto:organizer@example.org',
                 'recipientName' => null,
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -542,6 +554,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140818T200000Z
 RECURRENCE-ID:20140818T200000Z
@@ -551,9 +564,9 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+            ],
+        ];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -596,16 +609,16 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => null,
-                'recipient' => 'mailto:organizer@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => null,
+                'recipient'     => 'mailto:organizer@example.org',
                 'recipientName' => null,
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -613,6 +626,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;TZID=America/Toronto:20140818T200000
 RECURRENCE-ID;TZID=America/Toronto:20140818T200000
@@ -622,9 +636,9 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+            ],
+        ];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -666,16 +680,16 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => null,
-                'recipient' => 'mailto:organizer@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => null,
+                'recipient'     => 'mailto:organizer@example.org',
                 'recipientName' => null,
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -683,6 +697,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140818
 SUMMARY:Weekly meeting
@@ -693,9 +708,9 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+            ],
+        ];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -730,16 +745,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -747,6 +762,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140716T120000Z
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
@@ -755,11 +771,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -796,9 +812,9 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array();
+        $expected = [];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -852,10 +868,9 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $version = \Sabre\VObject\Version::VERSION;
-        $expected = array();
+        $expected = [];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -890,8 +905,8 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array();
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $expected = [];
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -926,16 +941,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -943,6 +958,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART;VALUE=DATE:20140716
 ORGANIZER;CN=Strunk:mailto:strunk@example.org
@@ -951,11 +967,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -1001,22 +1017,23 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140724T120000Z
 SUMMARY:Daily sprint
@@ -1027,11 +1044,11 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 
@@ -1091,24 +1108,23 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $version = \Sabre\VObject\Version::VERSION;
-
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140717T120000Z
 SUMMARY:B-day party
@@ -1120,11 +1136,11 @@ END:VCALENDAR
 
 ICS
 
-            ),
+            ],
 
-        );
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected);
+        $this->parse($oldMessage, $newMessage, $expected);
 
     }
 }
