@@ -27,16 +27,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'CANCEL',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:one@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'CANCEL',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:one@example.org',
                 'recipientName' => 'One',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -44,6 +44,7 @@ CALSCALE:GREGORIAN
 METHOD:CANCEL
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
@@ -53,17 +54,17 @@ ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
 END:VCALENDAR
 ICS
-            ),
+            ],
 
-            array(
-                'uid' => 'foobar',
-                'method' => 'CANCEL',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:two@example.org',
+            [
+                'uid'           => 'foobar',
+                'method'        => 'CANCEL',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:two@example.org',
                 'recipientName' => 'Two',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -71,6 +72,7 @@ CALSCALE:GREGORIAN
 METHOD:CANCEL
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
@@ -81,10 +83,10 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected, 'mailto:strunk@example.org');
+        $this->parse($oldMessage, $newMessage, $expected, 'mailto:strunk@example.org');
 
     }
 
@@ -111,8 +113,8 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
+        $expected = [
+            [
                 'uid'           => 'foobar',
                 'method'        => 'CANCEL',
                 'component'     => 'VEVENT',
@@ -128,6 +130,7 @@ CALSCALE:GREGORIAN
 METHOD:CANCEL
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
@@ -137,9 +140,9 @@ ATTENDEE;CN=One:mailto:one@example.org
 END:VEVENT
 END:VCALENDAR
 ICS
-            ),
+            ],
 
-            array(
+            [
                 'uid'           => 'foobar',
                 'method'        => 'CANCEL',
                 'component'     => 'VEVENT',
@@ -155,6 +158,7 @@ CALSCALE:GREGORIAN
 METHOD:CANCEL
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:2
 SUMMARY:foo
 DTSTART:20140716T120000Z
@@ -165,10 +169,10 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected, 'mailto:strunk@example.org');
+        $this->parse($oldMessage, $newMessage, $expected, 'mailto:strunk@example.org');
 
     }
 
@@ -195,8 +199,8 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
+        $expected = [
+            [
                 'uid'           => 'foobar',
                 'method'        => 'REPLY',
                 'component'     => 'VEVENT',
@@ -212,6 +216,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140716T120000Z
 DTEND:20140716T130000Z
@@ -221,15 +226,15 @@ ATTENDEE;PARTSTAT=DECLINED;CN=One:mailto:one@example.org
 END:VEVENT
 END:VCALENDAR
 ICS
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
+        $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
 
 
     }
 
-    function testAttendeeDeleteWithDuration() {
+    function testAttendeeReplyWithDuration() {
 
         $oldMessage = <<<ICS
 BEGIN:VCALENDAR
@@ -252,16 +257,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REPLY',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:one@example.org',
-                'senderName' => 'One',
-                'recipient' => 'mailto:strunk@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REPLY',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:one@example.org',
+                'senderName'    => 'One',
+                'recipient'     => 'mailto:strunk@example.org',
                 'recipientName' => 'Strunk',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -269,6 +274,7 @@ CALSCALE:GREGORIAN
 METHOD:REPLY
 BEGIN:VEVENT
 UID:foobar
+DTSTAMP:**ANY**
 SEQUENCE:1
 DTSTART:20140716T120000Z
 DURATION:PT1H
@@ -278,10 +284,10 @@ ATTENDEE;PARTSTAT=DECLINED;CN=One:mailto:one@example.org
 END:VEVENT
 END:VCALENDAR
 ICS
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
+        $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
 
 
     }
@@ -307,18 +313,16 @@ ICS;
 
         $newMessage = null;
 
-        $version = \Sabre\VObject\Version::VERSION;
+        $expected = [];
 
-        $expected = array();
-
-        $result = $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
+        $this->parse($oldMessage, $newMessage, $expected, 'mailto:one@example.org');
 
 
     }
 
     function testNoCalendar() {
 
-        $this->parse(null, null, array(), 'mailto:one@example.org');
+        $this->parse(null, null, [], 'mailto:one@example.org');
 
     }
 
@@ -333,7 +337,7 @@ SEQUENCE:1
 END:VTODO
 END:VCALENDAR
 ICS;
-        $this->parse($oldMessage, null, array(), 'mailto:one@example.org');
+        $this->parse($oldMessage, null, [], 'mailto:one@example.org');
 
     }
 
