@@ -2,7 +2,7 @@
 
 namespace Sabre\VObject\ITip;
 
-class BrokerNewEventTest extends \PHPUnit_Framework_TestCase {
+class BrokerNewEventTest extends BrokerTester {
 
     function testNoAttendee() {
 
@@ -16,7 +16,7 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $result = $this->parse($message);
+        $result = $this->parse(null, $message, []);
 
     }
 
@@ -30,7 +30,7 @@ END:VTODO
 END:VCALENDAR
 ICS;
 
-        $result = $this->parse($message);
+        $result = $this->parse(null, $message, []);
 
     }
 
@@ -66,20 +66,20 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:white@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:white@example.org',
                 'recipientName' => 'White',
-                'message' => $expectedMessage,
-            ),
-        );
+                'message'       => $expectedMessage,
+            ],
+        ];
 
-        $result = $this->parse($message, $expected);
+        $this->parse(null, $message, $expected, 'mailto:strunk@example.org');
 
     }
 
@@ -104,8 +104,7 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $expected = array();
-        $this->parse($message, array());
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
     /**
@@ -129,8 +128,7 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $expected = array();
-        $this->parse($message, array());
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
 
@@ -163,16 +161,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:one@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:one@example.org',
                 'recipientName' => 'One',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -191,16 +189,16 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:two@example.org',
+            ],
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:two@example.org',
                 'recipientName' => 'Two',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -228,16 +226,16 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:three@example.org',
+            ],
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:three@example.org',
                 'recipientName' => 'Three',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -255,10 +253,10 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($message, $expected);
+        $this->parse(null, $message, $expected, 'mailto:strunk@example.org');
 
     }
 
@@ -292,16 +290,16 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array(
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:one@example.org',
+        $expected = [
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:one@example.org',
                 'recipientName' => 'One',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -320,16 +318,16 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:two@example.org',
+            ],
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:two@example.org',
                 'recipientName' => 'Two',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -356,16 +354,16 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-            array(
-                'uid' => 'foobar',
-                'method' => 'REQUEST',
-                'component' => 'VEVENT',
-                'sender' => 'mailto:strunk@example.org',
-                'senderName' => 'Strunk',
-                'recipient' => 'mailto:three@example.org',
+            ],
+            [
+                'uid'           => 'foobar',
+                'method'        => 'REQUEST',
+                'component'     => 'VEVENT',
+                'sender'        => 'mailto:strunk@example.org',
+                'senderName'    => 'Strunk',
+                'recipient'     => 'mailto:three@example.org',
                 'recipientName' => 'Three',
-                'message' => <<<ICS
+                'message'       => <<<ICS
 BEGIN:VCALENDAR
 VERSION:2.0
 PRODID:-//Sabre//Sabre VObject $version//EN
@@ -383,10 +381,10 @@ END:VEVENT
 END:VCALENDAR
 ICS
 
-            ),
-        );
+            ],
+        ];
 
-        $result = $this->parse($message, $expected);
+        $this->parse(null, $message, $expected, 'mailto:strunk@example.org');
 
     }
 
@@ -407,8 +405,7 @@ ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
 
-        $expected = array();
-        $result = $this->parse($message, $expected);
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
 
@@ -442,13 +439,12 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $result = $this->parse($message, array());
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
 
     /**
      * @expectedException Sabre\VObject\ITip\SameOrganizerForAllComponentsException
-     *
      */
     function testChangingOrganizers() {
 
@@ -477,7 +473,7 @@ END:VCALENDAR
 ICS;
 
         $version = \Sabre\VObject\Version::VERSION;
-        $result = $this->parse($message, array());
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
     function testNoOrganizerHasAttendee() {
@@ -493,35 +489,7 @@ END:VEVENT
 END:VCALENDAR
 ICS;
 
-        $this->parse($message, array());
-
-    }
-
-    function parse($message, $expected = array()) {
-
-        $broker = new Broker();
-        $result = $broker->parseEvent($message, 'mailto:strunk@example.org');
-
-        $this->assertEquals(count($expected), count($result));
-
-        foreach($expected as $index=>$ex) {
-
-            $message = $result[$index];
-
-            foreach($ex as $key=>$val) {
-
-                if ($key==='message') {
-                    $this->assertEquals(
-                        str_replace("\n", "\r\n", $val),
-                        rtrim($message->message->serialize(), "\r\n")
-                    );
-                } else {
-                    $this->assertEquals($val, $message->$key);
-                }
-
-            }
-
-        }
+        $this->parse(null, $message, [], 'mailto:strunk@example.org');
 
     }
 
