@@ -12,16 +12,18 @@ class Issue40Test extends \PHPUnit_Framework_TestCase {
     function testEncode() {
 
         $card = new Component\VCard();
-        $card->add('N', array('van der Harten', array('Rene','J.'), "", 'Sir','R.D.O.N.'), array('SORT-AS' => array('Harten','Rene')));
+        $card->add('N', ['van der Harten', ['Rene', 'J.'], "", 'Sir', 'R.D.O.N.'], ['SORT-AS' => ['Harten', 'Rene']]);
 
-        $expected = implode("\r\n", array(
+        unset($card->UID);
+
+        $expected = implode("\r\n", [
             "BEGIN:VCARD",
-            "VERSION:3.0",
+            "VERSION:4.0",
             "PRODID:-//Sabre//Sabre VObject " . Version::VERSION . '//EN',
             "N;SORT-AS=Harten,Rene:van der Harten;Rene,J.;;Sir;R.D.O.N.",
             "END:VCARD",
             ""
-        ));
+        ]);
 
         $this->assertEquals($expected, $card->serialize());
 
