@@ -15,10 +15,10 @@ class FloatTest extends \PHPUnit_Framework_TestCase {
 
         $this->assertInstanceOf('Sabre\VObject\Property\FloatValue', $result->{'X-FLOAT'});
 
-        $this->assertEquals(array(
+        $this->assertEquals([
             0.234,
             1.245,
-        ), $result->{'X-FLOAT'}->getParts());
+        ], $result->{'X-FLOAT'}->getParts());
 
         $this->assertEquals(
             $input,
