@@ -2,9 +2,8 @@
 
 namespace Sabre\VObject\Recur;
 
-use
-    Sabre\VObject\Reader,
-    DateTime;
+use Sabre\VObject\Reader;
+use DateTime;
 
 class ByMonthInDailyTest extends \PHPUnit_Framework_TestCase {
 
@@ -38,20 +37,20 @@ ICS;
         $vcal = Reader::read($ics);
         $this->assertInstanceOf('Sabre\\VObject\\Component\\VCalendar', $vcal);
 
-        $vcal->expand(new DateTime('2013-09-28'), new DateTime('2014-09-11'));
+        $vcal = $vcal->expand(new DateTime('2013-09-28'), new DateTime('2014-09-11'));
 
         foreach ($vcal->VEVENT as $event) {
             $dates[] = $event->DTSTART->getValue();
         }
 
-        $expectedDates = array(
+        $expectedDates = [
             "20130929T160000Z",
             "20131006T160000Z",
             "20131013T160000Z",
             "20131020T160000Z",
             "20131027T160000Z",
             "20140907T160000Z"
-        );
+        ];
 
         $this->assertEquals($expectedDates, $dates, 'Recursed dates are restricted by month');
     }
