@@ -1,12 +1,13 @@
 <?php
 
-namespace Sabre\VObject;
+namespace Sabre\VObject\Recur\EventIterator;
 
-use
-    DateTime,
-    DateTimeZone;
+use DateTime;
+use Sabre\VObject\Reader;
 
-class RecurrenceIteratorMissingOverriddenTest extends \PHPUnit_Framework_TestCase {
+class MissingOverriddenTest extends \PHPUnit_Framework_TestCase {
+
+    use \Sabre\VObject\PHPUnitAssertions;
 
     function testExpand() {
 
@@ -33,9 +34,7 @@ ICS;
         $vcal = Reader::read($input);
         $this->assertInstanceOf('Sabre\\VObject\\Component\\VCalendar', $vcal);
 
-        $vcal->expand(new DateTime('2011-01-01'), new DateTime('2015-01-01'));
-
-        $result = $vcal->serialize();
+        $vcal = $vcal->expand(new DateTime('2011-01-01'), new DateTime('2015-01-01'));
 
         $output = <<<ICS
 BEGIN:VCALENDAR
@@ -45,6 +44,7 @@ UID:foo
 DTSTART:20130727T120000Z
 DURATION:PT1H
 SUMMARY:A
+RECURRENCE-ID:20130727T120000Z
 END:VEVENT
 BEGIN:VEVENT
 RECURRENCE-ID:20130728T120000Z
@@ -54,9 +54,8 @@ DURATION:PT1H
 SUMMARY:B
 END:VEVENT
 END:VCALENDAR
-
 ICS;
-        $this->assertEquals($output, str_replace("\r","",$result));
+        $this->assertVObjectEqualsVObject($output, $vcal);
     
     }
 
