@@ -12,7 +12,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=HOURLY;INTERVAL=3;COUNT=12',
             '2011-10-07 12:00:00',
-            array(
+            [
                 '2011-10-07 12:00:00',
                 '2011-10-07 15:00:00',
                 '2011-10-07 18:00:00',
@@ -25,7 +25,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-10-08 15:00:00',
                 '2011-10-08 18:00:00',
                 '2011-10-08 21:00:00',
-            )
+            ]
         );
 
     }
@@ -35,7 +35,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;INTERVAL=3;UNTIL=20111025T000000Z',
             '2011-10-07',
-            array(
+            [
                 '2011-10-07 00:00:00',
                 '2011-10-10 00:00:00',
                 '2011-10-13 00:00:00',
@@ -43,7 +43,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-10-19 00:00:00',
                 '2011-10-22 00:00:00',
                 '2011-10-25 00:00:00',
-            )
+            ]
         );
 
     }
@@ -53,7 +53,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;BYDAY=SA,SU;BYHOUR=6,7',
             '2011-10-08 06:00:00',
-            array(
+            [
                 '2011-10-08 06:00:00',
                 '2011-10-08 07:00:00',
                 '2011-10-09 06:00:00',
@@ -66,7 +66,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-10-22 07:00:00',
                 '2011-10-23 06:00:00',
                 '2011-10-23 07:00:00',
-            )
+            ]
         );
 
     }
@@ -76,7 +76,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;INTERVAL=2;BYHOUR=10,11,12,13,14,15',
             '2012-10-11 12:00:00',
-            array(
+            [
                 '2012-10-11 12:00:00',
                 '2012-10-11 13:00:00',
                 '2012-10-11 14:00:00',
@@ -89,7 +89,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2012-10-13 15:00:00',
                 '2012-10-15 10:00:00',
                 '2012-10-15 11:00:00',
-            )
+            ]
         );
 
     }
@@ -99,7 +99,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;INTERVAL=2;BYDAY=TU,WE,FR',
             '2011-10-07 12:00:00',
-            array(
+            [
                 '2011-10-07 12:00:00',
                 '2011-10-11 12:00:00',
                 '2011-10-19 12:00:00',
@@ -112,7 +112,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-11-18 12:00:00',
                 '2011-11-22 12:00:00',
                 '2011-11-30 12:00:00',
-            )
+            ]
         );
 
     }
@@ -122,13 +122,13 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;COUNT=5',
             '2014-08-01 18:03:00',
-            array(
+            [
                 '2014-08-01 18:03:00',
                 '2014-08-02 18:03:00',
                 '2014-08-03 18:03:00',
                 '2014-08-04 18:03:00',
                 '2014-08-05 18:03:00',
-            )
+            ]
         );
 
     }
@@ -138,14 +138,14 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;BYMONTH=9,10;BYDAY=SU',
             '2007-10-04 16:00:00',
-            array(
-                "2013-09-29 16:00:00",
-                "2013-10-06 16:00:00",
-                "2013-10-13 16:00:00",
-                "2013-10-20 16:00:00",
-                "2013-10-27 16:00:00",
-                "2014-09-07 16:00:00"
-            ),
+            [
+                '2013-09-29 16:00:00',
+                '2013-10-06 16:00:00',
+                '2013-10-13 16:00:00',
+                '2013-10-20 16:00:00',
+                '2013-10-27 16:00:00',
+                '2014-09-07 16:00:00'
+            ],
             '2013-09-28'
         );
 
@@ -156,7 +156,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=2;COUNT=10',
             '2011-10-07 00:00:00',
-            array(
+            [
                 '2011-10-07 00:00:00',
                 '2011-10-21 00:00:00',
                 '2011-11-04 00:00:00',
@@ -167,7 +167,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2012-01-13 00:00:00',
                 '2012-01-27 00:00:00',
                 '2012-02-10 00:00:00',
-            )
+            ]
         );
 
     }
@@ -177,12 +177,12 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=1;COUNT=4;BYDAY=MO;WKST=SA',
             '2014-08-01 00:00:00',
-            array(
+            [
                 '2014-08-01 00:00:00',
                 '2014-08-04 00:00:00',
                 '2014-08-11 00:00:00',
                 '2014-08-18 00:00:00',
-            )
+            ]
         );
 
     }
@@ -192,7 +192,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=2;BYDAY=TU,WE,FR;WKST=SU',
             '2011-10-07 00:00:00',
-            array(
+            [
                 '2011-10-07 00:00:00',
                 '2011-10-18 00:00:00',
                 '2011-10-19 00:00:00',
@@ -205,7 +205,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-11-18 00:00:00',
                 '2011-11-29 00:00:00',
                 '2011-11-30 00:00:00',
-            )
+            ]
         );
 
     }
@@ -215,7 +215,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=2;BYDAY=TU,WE,FR;WKST=MO;BYHOUR=8,9,10',
             '2011-10-07 08:00:00',
-            array(
+            [
                 '2011-10-07 08:00:00',
                 '2011-10-07 09:00:00',
                 '2011-10-07 10:00:00',
@@ -231,7 +231,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-11-01 08:00:00',
                 '2011-11-01 09:00:00',
                 '2011-11-01 10:00:00',
-            )
+            ]
         );
 
     }
@@ -241,7 +241,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=2;BYDAY=TU,WE,FR;WKST=SU',
             '2011-10-07 18:00:00',
-            array(
+            [
                 '2011-10-07 18:00:00',
                 '2011-10-18 18:00:00',
                 '2011-10-19 18:00:00',
@@ -254,7 +254,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-11-18 18:00:00',
                 '2011-11-29 18:00:00',
                 '2011-11-30 18:00:00',
-            )
+            ]
         );
 
     }
@@ -264,13 +264,13 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;INTERVAL=3;COUNT=5',
             '2011-12-05 00:00:00',
-            array(
+            [
                  '2011-12-05 00:00:00',
                  '2012-03-05 00:00:00',
                  '2012-06-05 00:00:00',
                  '2012-09-05 00:00:00',
                  '2012-12-05 00:00:00',
-            )
+            ]
         );
 
     }
@@ -280,7 +280,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;INTERVAL=2;COUNT=12',
             '2011-12-31 00:00:00',
-            array(
+            [
                 '2011-12-31 00:00:00',
                 '2012-08-31 00:00:00',
                 '2012-10-31 00:00:00',
@@ -293,7 +293,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2014-12-31 00:00:00',
                 '2015-08-31 00:00:00',
                 '2015-10-31 00:00:00',
-            )
+            ]
         );
 
     }
@@ -303,7 +303,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;INTERVAL=5;COUNT=9;BYMONTHDAY=1,31,-7',
             '2011-01-01 00:00:00',
-            array(
+            [
                 '2011-01-01 00:00:00',
                 '2011-01-25 00:00:00',
                 '2011-01-31 00:00:00',
@@ -313,7 +313,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-11-24 00:00:00',
                 '2012-04-01 00:00:00',
                 '2012-04-24 00:00:00',
-            )
+            ]
         );
 
     }
@@ -323,7 +323,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;INTERVAL=2;COUNT=16;BYDAY=MO,-2TU,+1WE,3TH',
             '2011-01-03 00:00:00',
-            array(
+            [
                 '2011-01-03 00:00:00',
                 '2011-01-05 00:00:00',
                 '2011-01-10 00:00:00',
@@ -340,7 +340,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-03-22 00:00:00',
                 '2011-03-28 00:00:00',
                 '2011-05-02 00:00:00',
-            )
+            ]
         );
 
     }
@@ -350,7 +350,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;COUNT=10;BYDAY=MO;BYMONTHDAY=1',
             '2011-08-01 00:00:00',
-            array(
+            [
                 '2011-08-01 00:00:00',
                 '2012-10-01 00:00:00',
                 '2013-04-01 00:00:00',
@@ -361,7 +361,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2016-02-01 00:00:00',
                 '2016-08-01 00:00:00',
                 '2017-05-01 00:00:00',
-            )
+            ]
         );
 
     }
@@ -371,7 +371,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;COUNT=10;BYDAY=MO,TU,WE,TH,FR;BYSETPOS=1,-1',
             '2011-01-03 00:00:00',
-            array(
+            [
                 '2011-01-03 00:00:00',
                 '2011-01-31 00:00:00',
                 '2011-02-01 00:00:00',
@@ -382,7 +382,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2011-04-29 00:00:00',
                 '2011-05-02 00:00:00',
                 '2011-05-31 00:00:00',
-            )
+            ]
         );
 
     }
@@ -392,7 +392,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;COUNT=10;INTERVAL=3',
             '2011-01-01 00:00:00',
-            array(
+            [
                 '2011-01-01 00:00:00',
                 '2014-01-01 00:00:00',
                 '2017-01-01 00:00:00',
@@ -403,7 +403,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2032-01-01 00:00:00',
                 '2035-01-01 00:00:00',
                 '2038-01-01 00:00:00',
-            )
+            ]
         );
     }
 
@@ -412,11 +412,11 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;COUNT=3',
             '2012-02-29 00:00:00',
-            array(
+            [
                 '2012-02-29 00:00:00',
                 '2016-02-29 00:00:00',
                 '2020-02-29 00:00:00',
-            )
+            ]
         );
     }
 
@@ -425,7 +425,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;COUNT=8;INTERVAL=4;BYMONTH=4,10',
             '2011-04-07 00:00:00',
-            array(
+            [
                 '2011-04-07 00:00:00',
                 '2011-10-07 00:00:00',
                 '2015-04-07 00:00:00',
@@ -434,7 +434,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2019-10-07 00:00:00',
                 '2023-04-07 00:00:00',
                 '2023-10-07 00:00:00',
-            )
+            ]
         );
 
     }
@@ -444,7 +444,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;COUNT=8;INTERVAL=5;BYMONTH=4,10;BYDAY=1MO,-1SU',
             '2011-04-04 00:00:00',
-            array(
+            [
                 '2011-04-04 00:00:00',
                 '2011-04-24 00:00:00',
                 '2011-10-03 00:00:00',
@@ -453,7 +453,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2016-04-24 00:00:00',
                 '2016-10-03 00:00:00',
                 '2016-10-30 00:00:00',
-            )
+            ]
         );
 
     }
@@ -465,11 +465,11 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;COUNT=8;INTERVAL=5;BYMONTH=4,10;BYDAY=1MO,-1SU',
             '2011-04-04 00:00:00',
-            array(),
+            [],
             '2020-05-05 00:00:00'
         );
 
-    } 
+    }
 
     /**
      * The bug that was in the
@@ -486,9 +486,9 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;INTERVAL=1;UNTIL=20071030T035959Z;BYDAY=5TU',
             '2007-10-04 14:46:42',
-            array(
-                "2007-10-04 14:46:42",
-            )
+            [
+                '2007-10-04 14:46:42',
+            ]
         );
 
     }
@@ -502,7 +502,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=WEEKLY;BYDAY=MO;UNTIL=20090704T205959Z;INTERVAL=1',
             '2009-04-20 18:00:00',
-            array(
+            [
                 '2009-04-20 18:00:00',
                 '2009-04-27 18:00:00',
                 '2009-05-04 18:00:00',
@@ -514,7 +514,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2009-06-15 18:00:00',
                 '2009-06-22 18:00:00',
                 '2009-06-29 18:00:00',
-            )
+            ]
         );
 
     }
@@ -527,9 +527,9 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=YEARLY;INTERVAL=1;UNTIL=20120203T225959Z;BYMONTH=2;BYSETPOS=1;BYDAY=SU,MO,TU,WE,TH,FR,SA',
             '2012-01-01 15:45:00',
-            array(
+            [
                 '2012-02-01 15:45:00',
-            ),
+            ],
             '2012-01-29 23:00:00'
         );
 
@@ -541,51 +541,51 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
      * this means we increase the current day (or week, month) by 0, this also
      * results in an infinite loop.
      *
-     * @expectedException InvalidArgumentException
+     * @expectedException \Sabre\VObject\InvalidDataException
      */
     function testZeroInterval() {
 
         $this->parse(
             'FREQ=YEARLY;INTERVAL=0',
             '2012-08-24 14:57:00',
-            array(),
+            [],
             '2013-01-01 23:00:00'
         );
 
     }
 
     /**
-     * @expectedException InvalidArgumentException
+     * @expectedException \Sabre\VObject\InvalidDataException
      */
     function testInvalidFreq() {
 
         $this->parse(
             'FREQ=SMONTHLY;INTERVAL=3;UNTIL=20111025T000000Z',
             '2011-10-07',
-            array()
+            []
         );
 
     }
 
     /**
-     * @expectedException InvalidArgumentException
+     * @expectedException \Sabre\VObject\InvalidDataException
      */
     function testByDayBadOffset() {
 
         $this->parse(
             'FREQ=WEEKLY;INTERVAL=1;COUNT=4;BYDAY=0MO;WKST=SA',
             '2014-08-01 00:00:00',
-            array()
+            []
         );
 
     }
 
-    function testUntilBeginHAsTimezone() {
+    function testUntilBeginHasTimezone() {
 
         $this->parse(
             'FREQ=WEEKLY;UNTIL=20131118T183000',
             '2013-09-23 18:30:00',
-            array(
+            [
                 '2013-09-23 18:30:00',
                 '2013-09-30 18:30:00',
                 '2013-10-07 18:30:00',
@@ -595,7 +595,7 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
                 '2013-11-04 18:30:00',
                 '2013-11-11 18:30:00',
                 '2013-11-18 18:30:00',
-            ),
+            ],
             null,
             'America/New_York'
         );
@@ -607,9 +607,9 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;UNTIL=20140101T000000Z',
             '2014-08-02 00:15:00',
-            array(
+            [
                 '2014-08-02 00:15:00',
-            )
+            ]
         );
 
     }
@@ -619,10 +619,10 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=DAILY;BYSECOND=1;BYMINUTE=1;BYYEARDAY=1;BYWEEKNO=1;COUNT=2',
             '2014-08-02 00:15:00',
-            array(
+            [
                 '2014-08-02 00:15:00',
                 '2014-08-03 00:15:00',
-            )
+            ]
         );
 
     }
@@ -632,25 +632,25 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
         $this->parse(
             'FREQ=MONTHLY;BYDAY=-4TH,-5TH;COUNT=4',
             '2015-01-01 00:15:00',
-            array(
+            [
                 '2015-01-01 00:15:00',
                 '2015-01-08 00:15:00',
                 '2015-02-05 00:15:00',
                 '2015-03-05 00:15:00'
-            )
+            ]
         );
 
     }
 
     /**
-     * @expectedException InvalidArgumentException
+     * @expectedException \Sabre\VObject\InvalidDataException
      */
     function testUnsupportedPart() {
 
         $this->parse(
             'FREQ=DAILY;BYWODAN=1',
             '2014-08-02 00:15:00',
-            array()
+            []
         );
 
     }
@@ -690,8 +690,8 @@ class RRuleIteratorTest extends \PHPUnit_Framework_TestCase {
             $parser->fastForward(new DateTime($fastForward));
         }
 
-        $result = array();
-        while($parser->valid()) {
+        $result = [];
+        while ($parser->valid()) {
 
             $item = $parser->current();
             $result[] = $item->format('Y-m-d H:i:s');
